/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.file.config;

public class BaseSourceConfig {
    public static final String FILE_TYPE = "type";
    public static final String FILE_PATH = "path";
    public static final String SCHEMA = "schema";
    public static final String DELIMITER = "delimiter";
    public static final String DATE_FORMAT = "date_format";
    public static final String DATETIME_FORMAT = "datetime_format";
    public static final String TIME_FORMAT = "time_format";
    public static final String PARSE_PARTITION_FROM_PATH = "parse_partition_from_path";
}
